summaryrefslogtreecommitdiff
path: root/actions/public.php
diff options
context:
space:
mode:
authorEvan Prodromou <evan@controlyourself.ca>2009-08-25 18:12:20 -0400
committerEvan Prodromou <evan@controlyourself.ca>2009-08-25 18:12:20 -0400
commitc8b8f07af14ad2ce9d0c0267962dd3bbf6473a4b (patch)
tree2ed665ca0639c845f425c671fdffccc01e6ddc3a /actions/public.php
parentd0baab6978f1959382d568d26cc9f8f552a7b764 (diff)
change Laconica and Control Yourself to StatusNet in PHP files
Diffstat (limited to 'actions/public.php')
-rw-r--r--actions/public.php12
1 files changed, 6 insertions, 6 deletions
diff --git a/actions/public.php b/actions/public.php
index 2cf2e96e6..aea730606 100644
--- a/actions/public.php
+++ b/actions/public.php
@@ -1,6 +1,6 @@
<?php
/**
* Laconica, the distributed open-source microblogging tool
*
* Action for displaying the public stream
*
@@ -20,9 +20,9 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @category Public
- * @package Laconica
+ * @package StatusNet
* @author Evan Prodromou <evan@controlyourself.ca>
- * @copyright 2008-2009 Control Yourself, Inc.
+ * @copyright 2008-2009 StatusNet, Inc.
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
* @link http://laconi.ca/
*/
@@ -43,7 +43,7 @@ define('MAX_PUBLIC_PAGE', 100);
* Action for displaying the public stream
*
* @category Public
- * @package Laconica
+ * @package StatusNet
* @author Evan Prodromou <evan@controlyourself.ca>
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
* @link http://laconi.ca/
@@ -245,13 +245,13 @@ class PublicAction extends Action
{
if (! (common_config('site','closed') || common_config('site','inviteonly'))) {
$m = sprintf(_('This is %%%%site.name%%%%, a [micro-blogging](http://en.wikipedia.org/wiki/Micro-blogging) service ' .
- 'based on the Free Software [Laconica](http://laconi.ca/) tool. ' .
+ 'based on the Free Software [StatusNet](http://laconi.ca/) tool. ' .
'[Join now](%%%%action.%s%%%%) to share notices about yourself with friends, family, and colleagues! ' .
'([Read more](%%%%doc.help%%%%))'),
(!common_config('site','openidonly')) ? 'register' : 'openidlogin');
} else {
$m = _('This is %%site.name%%, a [micro-blogging](http://en.wikipedia.org/wiki/Micro-blogging) service ' .
- 'based on the Free Software [Laconica](http://laconi.ca/) tool.');
+ 'based on the Free Software [StatusNet](http://laconi.ca/) tool.');
}
$this->elementStart('div', array('id' => 'anon_notice'));
$this->raw(common_markup_to_html($m));
@@ -1,6 +1,6 @@
<?php
/**
- * Laconica, the distributed open-source microblogging tool
+ * StatusNet, the distributed open-source microblogging tool
*
* Action for displaying the public stream